@@ -1,6 +1,8 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 #include "loadprev.h"
+#include "memorycardmanager.h"
+
 QString game;
 #ifdef Q_WS_MAEMO_5
 QString cfg_path="/home/user/.config/Team16/psx4m/";
@@ -15,6 +17,7 @@ MainWindow::MainWindow(QWidget *parent) :
 {
     ui->setupUi(this);
 
+    myProcess = NULL;
     settings=new QSettings();
     bios_path=settings->value("bios_path","/home/user/MyDocs/").toString();
     if (bios_path.right(1)!="/") bios_path+="/";
@@ -51,6 +54,7 @@ MainWindow::MainWindow(QWidget *parent) :
     this->menuBar()->addAction("Default config",this,SLOT(def_cfg()));
     this->menuBar()->addAction("GUI config",this,SLOT(gui_cfg()));
     this->menuBar()->addAction("Configure keys",this,SLOT(set_keys()));
+    this->menuBar()->addAction("Edit Memory cards",this,SLOT(memory_cards()));
     this->menuBar()->addAction("Help",this,SLOT(open_help()));
 
     connect(ui->listWidget,SIGNAL(currentRowChanged(int)),this,SLOT(currentRowChanged(int)));
@@ -116,8 +120,7 @@ void MainWindow::rom_exec(){
             //args<<roms.value(ui->listWidget->currentRow())<<"-save_name"<<(ui->listWidget->currentItem()->text());
             args<<roms.value(ui->listWidget->currentRow());
             qDebug (QString("%1 %2").arg("/opt/maemo/usr/games/"+current_core).arg(args.join(" ")).toAscii());
-            /*if (!myProcess->startDetached("/opt/maemo/usr/games/"+current_core, args,"/home/user/"))
-                process_finished(-1);*/
+
             myProcess->start("/opt/maemo/usr/games/"+current_core, args);
             if (!myProcess->waitForStarted(10000)){
                 qDebug() << "Failed to start process.";
@@ -272,3 +275,10 @@ void MainWindow::rom_config()
         cfg->show();
     }
 }
+
+void MainWindow::memory_cards()
+{
+    MemoryCardManager* dlg = new MemoryCardManager(this);
+    dlg->show();
+    dlg = NULL;
+}
