@@ -1,5 +1,7 @@
 #include "options.h"
 #include "ui_options.h"
+#include "memorycardselect.h"
+
 QStringList current_config=QStringList();
 QString current_core="";
 options::options(QWidget *parent) :
@@ -12,21 +14,19 @@ options::options(QWidget *parent) :
 #endif
     this->setWindowFlags(this->windowFlags() | Qt::Window);
     connect (ui->checkBox_2,SIGNAL(clicked()),this,SLOT(psx4m_hwa_block()));
+    connect(ui->pbnMemoryCard1, SIGNAL(clicked()),this,SLOT(memory_card_1()));
+    connect(ui->pbnMemoryCard2, SIGNAL(clicked()),this,SLOT(memory_card_2()));
 
-
-        QDir dir( bios_path);
-                 dir.setFilter(QDir::Files);
-                 dir.setSorting(QDir::Name);
-        dir.setNameFilters(QStringList()<<"*.bin");
-
-                 QFileInfoList list = dir.entryInfoList();
-                 for (int i = 0; i < list.size(); ++i) {
-                     QFileInfo fileInfo = list.at(i);
-                     ui->comboBox_4->addItem(fileInfo.fileName());
-                 }
-
-                 load_cfg();
-
+    QDir dir( bios_path);
+    dir.setFilter(QDir::Files);
+    dir.setSorting(QDir::Name);
+    dir.setNameFilters(QStringList()<<"*.bin");
+    QFileInfoList list = dir.entryInfoList();
+    for (int i = 0; i < list.size(); ++i) {
+        QFileInfo fileInfo = list.at(i);
+        ui->comboBox_4->addItem(fileInfo.fileName());
+    }
+    load_cfg();
 }
 
 options::~options()
@@ -53,27 +53,37 @@ void options::hideEvent(QHideEvent *){
 }
 
 void options::load_cfg(){
+
+    m_MemoryCard1 = "/home/user/.pcsx/memcards/card1.mcd";
+    m_MemoryCard2 = "/home/user/.pcsx/memcards/card2.mcd";
+
+    QFileInfo f(m_MemoryCard1);
+    ui->pbnMemoryCard1->setText(f.fileName());
+    f = QFileInfo(m_MemoryCard2);
+    ui->pbnMemoryCard2->setText(f.fileName());
+
     QString path="";
     if (game!="")
-        path=cfg_path+game;
+       path=cfg_path+game;
     else
        path=cfg_path+"default";
 
-    QStringList configs=QStringList()<<"core"<<"sound"<<"bios";
-    configs<<"psx4m-cycle"<<"psx4m-frame"<<"psx4m-hwa"<<"psx4m-fps"<<"psx4m-fullscreen"<<"psx4m-afix";
-    configs<<"pcsx-threadedspu"<<"pcsx-hwa"<<"pcsx-bios"<<"pcsx-frameskip";
-    configs<<"accel";
-    configs<<"cdda" <<    "xa" <<    "rcnt"<<    "sio"<<    "spuirq"<<    "vsync";
-    configs<<"fsaa"<<"pcsx-fullscreen";
-    configs<<"pcsx-fps"<<"pcsx-cpu"<<"pcsx-nofl";
+    QStringList configs = QStringList() << "core" << "sound" << "bios";
+    configs << "psx4m-cycle" << "psx4m-frame" << "psx4m-hwa" << "psx4m-fps" << "psx4m-fullscreen" << "psx4m-afix";
+    configs << "pcsx-threadedspu" << "pcsx-hwa" << "pcsx-bios" << "pcsx-frameskip";
+    configs << "accel" << "cdda" << "xa" << "rcnt" << "sio" << "spuirq" << "vsync" << "fsaa" << "pcsx-fullscreen";
+    configs << "pcsx-fps" << "pcsx-cpu" << "pcsx-nofl" << "mcd1" << "mcd2" << "spu_reverb" << "spu_interpolation";
+    configs << "region";
 
     ui->comboBox_5->setCurrentIndex(0);
     ui->checkBox_4->setChecked(false);
     ui->checkBox_18->setChecked(false);
     ui->checkBox_19->setChecked(false);
+    ui->chkReverb->setChecked(false);
+    ui->cmbInterpolation->setCurrentIndex(0);
+    ui->cmbRegion->setCurrentIndex(0);
 
     if (QFile::exists(path)){
-
         QFile file(path);
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
             qDebug(QString("Can't open file : %1\n").arg(path).toAscii());
@@ -92,10 +102,10 @@ void options::load_cfg(){
                      if (value=="1")ui->checkBox->setChecked(true);else ui->checkBox->setChecked(false);
                      break;
                  case 2: // bios
-if (value=="")value="scph1001.bin";
+                     if (value=="")value="scph1001.bin";
                      if (ui->comboBox_4->findText(value)!=1)
                          ui->comboBox_4->setCurrentIndex(ui->comboBox_4->findText(value));
-                         break;
+                     break;
                  case 3: // psx4m-cycle
                      if (ui->comboBox->findText(value)!=1)
                          ui->comboBox->setCurrentIndex(ui->comboBox->findText(value));
@@ -166,6 +176,29 @@ if (value=="")value="scph1001.bin";
                  case 24:
                       if (value=="1")ui->checkBox_19->setChecked(true);else ui->checkBox_19->setChecked(false);
                       break;
+                 case 25:{
+                         m_MemoryCard1 = value;
+                         f = QFileInfo(m_MemoryCard1);
+                         ui->pbnMemoryCard1->setText(f.fileName());
+                      }
+                      break;
+                 case 26:{
+                         m_MemoryCard2 = value;
+                         f = QFileInfo(m_MemoryCard2);
+                         ui->pbnMemoryCard2->setText(f.fileName());
+                      }
+                      break;
+                 case 27:
+                      if (value=="1")ui->chkReverb->setChecked(true);else ui->chkReverb->setChecked(false);
+                      break;
+                 case 28:
+                     if (ui->cmbInterpolation->findText(value)!=1)
+                         ui->cmbInterpolation->setCurrentIndex(ui->cmbInterpolation->findText(value));
+                     break;
+                 case 29:
+                     if (ui->cmbRegion->findText(value)!=1)
+                         ui->cmbRegion->setCurrentIndex(ui->cmbRegion->findText(value));
+                     break;
                  default:
                       qDebug(QString("Undefined setting:%1 = %2").arg(line.at(0)).arg(value).toAscii());
                       break;
@@ -194,8 +227,8 @@ void options::createCfg(){
     if (ui->checkBox_13->isChecked())current_config<<"-spuirq";
     if (ui->checkBox_14->isChecked())current_config<<"-rcnt";
     if (ui->checkBox_15->isChecked())current_config<<"-vsync";
-
-
+    current_config<<"-mcd1"<<m_MemoryCard1;
+    current_config<<"-mcd2"<<m_MemoryCard2;
 
     if (ui->radioButton_2->isChecked())
     {
@@ -217,6 +250,11 @@ void options::createCfg(){
         if (ui->checkBox_18->isChecked())current_config<<"-cpu";
         if (ui->checkBox_19->isChecked())current_config<<"-nofl";
 
+        if (ui->chkReverb->isChecked())current_config<<"-spu_reverb"<<"1";
+        if (ui->cmbInterpolation->currentIndex()>=0)
+            current_config<<"-spu_interpolation"<<QString("%1").arg(ui->cmbInterpolation->currentIndex());
+        if (ui->cmbRegion->currentIndex()>=0)
+            current_config<<"-region"<<QString("%1").arg(ui->cmbRegion->currentIndex() - 1);
 
         current_config<<"-cdfile";
 
@@ -284,8 +322,13 @@ void options::save_cfg(){
                    "fsaa=%21\n" \
                    "pcsx-fullscreen=%22\n"\
                    "pcsx-fps=%23\n" \
-                "pcsx-cpu=%24\n" \
-                "pcsx-nofl=%25\n")
+                   "pcsx-cpu=%24\n" \
+                   "pcsx-nofl=%25\n" \
+                   "mcd1=%26\n" \
+                   "mcd2=%27\n" \
+                   "spu_reverb=%28\n" \
+                   "spu_interpolation=%29\n" \
+                   "region=%30\n")
             .arg(ui->radioButton_2->isChecked()?"1":"0")
             .arg(ui->checkBox->isChecked()?"1":"0")
             .arg(ui->comboBox_4->currentText())
@@ -311,7 +354,11 @@ void options::save_cfg(){
             .arg(ui->checkBox_4->isChecked()?"1":"0")
             .arg(ui->checkBox_18->isChecked()?"1":"0")
             .arg(ui->checkBox_19->isChecked()?"1":"0")
-;
+            .arg(m_MemoryCard1)
+            .arg(m_MemoryCard2)
+            .arg(ui->chkReverb->isChecked()?"1":"0")
+            .arg(ui->cmbInterpolation->currentText())
+            .arg(ui->cmbRegion->currentText());
 
     QFile file(path);
     QFileInfo pathInfo(path);
@@ -320,13 +367,13 @@ void options::save_cfg(){
 
     if (!file.open(QIODevice::WriteOnly | QIODevice::Text)){
         qDebug(QString("Can't save %1").arg(path).toAscii());
-        return;}
+        return;
+    }
 
-         QTextStream out(&file);
-         out <<config;
-
-         file.close();
+    QTextStream out(&file);
+    out <<config;
 
+    file.close();
 }
 
 void options::psx4m_hwa_block(){
@@ -344,3 +391,57 @@ void options::psx4m_hwa_block(){
         ui->checkBox_16->setEnabled(false);
     }
 }
+
+void options::memory_card_1()
+{
+#ifdef Q_WS_MAEMO_5
+    QString filename = GetMemoryCardName();
+#else
+    QString filename = QFileDialog::getOpenFileName(this, tr("Open Memory card"),
+                                                    QDir::homePath(),
+                                                    tr("Memory cards (*.mcd)"));
+#endif
+    if (!filename.isEmpty()){
+        m_MemoryCard1 = filename;
+        QFileInfo f(m_MemoryCard1);
+        ui->pbnMemoryCard1->setText(f.fileName());
+    }
+}
+
+void options::memory_card_2()
+{
+#ifdef Q_WS_MAEMO_5
+    QString filename = GetMemoryCardName();
+#else
+    QString filename = QFileDialog::getOpenFileName(this, tr("Open Memory card"),
+                                                    QDir::homePath(),
+                                                    tr("Memory cards (*.mcd)"));
+#endif
+    if (!filename.isEmpty()){
+        m_MemoryCard2 = filename;
+        QFileInfo f(m_MemoryCard2);
+        ui->pbnMemoryCard2->setText(f.fileName());
+    }
+}
+
+#ifdef Q_WS_MAEMO_5
+QString options::GetMemoryCardName()
+{
+    MemoryCardSelect* dlg = new MemoryCardSelect(this);
+    if (dlg->exec() == QDialog::Accepted)
+        return dlg->Selected();
+    return "";
+}
+#endif
+
+void options::show()
+{
+    ui->tabWidget->setCurrentIndex(0);
+
+    ui->scrollArea->verticalScrollBar()->setValue(0);
+    ui->scrollArea_2->verticalScrollBar()->setValue(0);
+    ui->scrollArea_3->verticalScrollBar()->setValue(0);
+    ui->scrollArea_4->verticalScrollBar()->setValue(0);
+
+    QWidget::show();
+}
